@@ -1,6 +1,8 @@
 import getpass
 import os
 import subprocess
+import requests
+from re import sub
 
 def Connect(password):
     subprocess.call("apt-get install -qq -o=Dpkg::Use-Pty=0 openssh-server pwgen > /dev/null", shell=True)
@@ -23,5 +25,17 @@ def VSConfig(str):
     print("\tUser root")
     print(f"\tPort {str[21:26]}")
 
+def GetSSH():
+    tun = requests.get('http://localhost:4040/api/tunnels')
+    url = tun.json()['tunnels'][0]['public_url']
+    str_ssh = sub("tcp://", "", url)
+    str_ssh = sub(":", " -p ", str_ssh)
+    str_ssh = "ssh root@" + str_ssh
+    print("Tunnel URL: ")
+    print(url)
+    print("SSH Command: ")
+    print(str_ssh)
+    
+
 def Kill():
-    os.system("kill $(ps aux | grep './ngrok' | awk '{print $2}')")
\ No newline at end of file
+    os.system("kill $(ps aux | grep './ngrok' | awk '{print $2}')")
